# IncotermEnum

* `EXW` - EXW (Ex Works) * `DAP` - DAP (Delivered At Place)

## Enum

* `EXW` (value: `'EXW'`)

* `DAP` (value: `'DAP'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


